@@ -15,9 +15,14 @@
 
 
 # Standard library imports.
-import pickle, glob, logging, os
+import glob
+import logging
+import os
 from os.path import join, splitext
 
+# Third-party library imports.
+import six.moves.cPickle as pickle
+
 # Enthought library imports.
 from apptools.io.api import File
 from traits.api import Any, Dict, Instance, Property, Str
