@@ -1,10 +1,13 @@
 """ The default implementation of a node in a preferences hierarchy. """
 
-
+from __future__ import print_function
 
 # Standard library imports.
 import logging, threading
 
+# Third-party library imports.
+import six
+
 # Enthought library imports.
 from traits.api import Any, Callable, Dict, HasTraits, Instance, List
 from traits.api import Property, Str, Undefined, provides
@@ -367,7 +370,7 @@ class Preferences(HasTraits):
 
         # 'name' is the section name, 'value' is a dictionary containing the
         # name/value pairs in the section (the actual preferences ;^).
-        for name, value in list(config_obj.items()):
+        for name, value in config_obj.items():
             # Create/get the node from the section name.
             components = name.split('.')
 
@@ -546,7 +549,7 @@ class Preferences(HasTraits):
         # everything must be unicode encoded so that ConfigObj configuration
         # can properly serialize the data. Python str are supposed to be ASCII
         # encoded.
-        value = str(value)
+        value = six.text_type(value)
 
         self._lk.acquire()
         old = self._preferences.get(key)
@@ -578,7 +581,7 @@ class Preferences(HasTraits):
         print(indent, 'Node(%s)' % self.name, self._preferences)
         indent += '  '
 
-        for child in list(self._children.values()):
+        for child in self._children.values():
             child.dump(indent)
 
         return
